@@ -10,7 +10,7 @@ SAfrica_LO_Latest_main
 </name>
 
 <description>  
-Xhosa localisation of LibreOffice (no database)
+Language Meta-Package for LibreOffice all 11 South African languages (no database)
 </description>
 
 <installable>
@@ -30,7 +30,7 @@ libreoffice-draw
 libreoffice-impress
 libreoffice-math
 libreoffice-writer
-libreoffice-l10n-xh
+libreoffice-l10n-za
 libreoffice-gtk3
 </install_package_names>
 
@@ -45,7 +45,7 @@ libreoffice-draw
 libreoffice-impress
 libreoffice-math
 libreoffice-writer
-libreoffice-l10n-xh
+libreoffice-l10n-za
 libreoffice-gtk3
 </uninstall_package_names>
 
